@@ -9,8 +9,8 @@ class SharePointList:
     '''
     '''
 
-    settings = {}
-    _items = {}
+    settings = None
+    _items = None
     sharepoint_site = ""
     SPItem = SharePointListItem
 
@@ -51,7 +51,7 @@ class SharePointList:
         '''
         if self._items is None:
             self._items = {}
-        return self._items.values()
+        return list(self._items.values())
 
     @property
     def Title(self) -> str:
@@ -62,6 +62,8 @@ class SharePointList:
         return self.settings['Id']
 
     def append_items(self, items):
+        if self._items is None:
+            self._items = {}
 
         if isinstance(items, list):
             for item in items:
